TypedParameter

Enum TypedParameter 

pub enum TypedParameter {
Show 25 variants Int { default: Option<i32>, }, Float { default: Option<f32>, }, String { default: Option<String>, }, Color { default: Option<[f32; 3]>, space: Option<Ustr>, }, Point { default: Option<[f32; 3]>, space: Option<Ustr>, }, Vector { default: Option<[f32; 3]>, space: Option<Ustr>, }, Normal { default: Option<[f32; 3]>, space: Option<Ustr>, }, Matrix { default: Option<[f32; 16]>, }, IntArray { size: usize, default: Option<Vec<i32>>, }, FloatArray { size: usize, default: Option<Vec<f32>>, }, StringArray { size: usize, default: Option<Vec<String>>, }, ColorArray { size: usize, default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, PointArray { size: usize, default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, VectorArray { size: usize, default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, NormalArray { size: usize, default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, MatrixArray { size: usize, default: Option<Vec<[f32; 16]>>, }, IntDynamicArray { default: Option<Vec<i32>>, }, FloatDynamicArray { default: Option<Vec<f32>>, }, StringDynamicArray { default: Option<Vec<String>>, }, ColorDynamicArray { default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, PointDynamicArray { default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, VectorDynamicArray { default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, NormalDynamicArray { default: Option<Vec<[f32; 3]>>, space: Option<Ustr>, }, MatrixDynamicArray { default: Option<Vec<[f32; 16]>>, }, Closure { closure_type: Ustr, },
}
A typed parameter that unifies type information with its potential value.

This design makes it impossible to have type mismatches - you can’t accidentally assign an integer default to a color parameter, for example.

Variants



Int

Integer parameter

Fields

default: Option<i32>


Float

Float parameter

Fields

default: Option<f32>


String

String parameter

Fields

default: Option<String>


Color

RGB color (3 floats)

Fields

default: Option<[f32; 3]>
space: Option<Ustr>


Point

3D point (3 floats)

Fields

default: Option<[f32; 3]>
space: Option<Ustr>


Vector

3D vector (3 floats)

Fields

default: Option<[f32; 3]>
space: Option<Ustr>


Normal

Surface normal (3 floats)

Fields

default: Option<[f32; 3]>
space: Option<Ustr>


Matrix

4x4 transformation matrix (16 floats)

Fields

default: Option<[f32; 16]>


IntArray

Fixed-size array of integers

Fields

size: usize
default: Option<Vec<i32>>


FloatArray

Fixed-size array of floats

Fields

size: usize
default: Option<Vec<f32>>


StringArray

Fixed-size array of strings

Fields

size: usize
default: Option<Vec<String>>


ColorArray

Fixed-size array of colors

Fields

size: usize
default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


PointArray

Fixed-size array of points

Fields

size: usize
default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


VectorArray

Fixed-size array of vectors

Fields

size: usize
default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


NormalArray

Fixed-size array of normals

Fields

size: usize
default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


MatrixArray

Fixed-size array of matrices

Fields

size: usize
default: Option<Vec<[f32; 16]>>


IntDynamicArray

Dynamic (unsized) array of integers

Fields

default: Option<Vec<i32>>


FloatDynamicArray

Dynamic array of floats

Fields

default: Option<Vec<f32>>


StringDynamicArray

Dynamic array of strings

Fields

default: Option<Vec<String>>


ColorDynamicArray

Dynamic array of colors

Fields

default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


PointDynamicArray

Dynamic array of points

Fields

default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


VectorDynamicArray

Dynamic array of vectors

Fields

default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


NormalDynamicArray

Dynamic array of normals

Fields

default: Option<Vec<[f32; 3]>>
space: Option<Ustr>


MatrixDynamicArray

Dynamic array of matrices

Fields

default: Option<Vec<[f32; 16]>>


Closure

Closure (BSDF, etc.) - no default values

Fields

closure_type: Ustr

Implementations

Source

impl TypedParameter

pub fn has_default(&self) -> bool

Check if this parameter has a default value.

pub fn is_array(&self) -> bool

Check if this is an array type.

pub fn is_dynamic_array(&self) -> bool

Check if this is a dynamic (unsized) array.

pub fn is_closure(&self) -> bool

Check if this is a closure type.

pub fn type_name(&self) -> &'static str

Get the type name as a string.