pub enum TypedParameter {
Show 25 variants
Int {
default: Option<i32>,
},
Float {
default: Option<f32>,
},
String {
default: Option<String>,
},
Color {
default: Option<[f32; 3]>,
space: Option<Ustr>,
},
Point {
default: Option<[f32; 3]>,
space: Option<Ustr>,
},
Vector {
default: Option<[f32; 3]>,
space: Option<Ustr>,
},
Normal {
default: Option<[f32; 3]>,
space: Option<Ustr>,
},
Matrix {
default: Option<[f32; 16]>,
},
IntArray {
size: usize,
default: Option<Vec<i32>>,
},
FloatArray {
size: usize,
default: Option<Vec<f32>>,
},
StringArray {
size: usize,
default: Option<Vec<String>>,
},
ColorArray {
size: usize,
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
PointArray {
size: usize,
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
VectorArray {
size: usize,
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
NormalArray {
size: usize,
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
MatrixArray {
size: usize,
default: Option<Vec<[f32; 16]>>,
},
IntDynamicArray {
default: Option<Vec<i32>>,
},
FloatDynamicArray {
default: Option<Vec<f32>>,
},
StringDynamicArray {
default: Option<Vec<String>>,
},
ColorDynamicArray {
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
PointDynamicArray {
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
VectorDynamicArray {
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
NormalDynamicArray {
default: Option<Vec<[f32; 3]>>,
space: Option<Ustr>,
},
MatrixDynamicArray {
default: Option<Vec<[f32; 16]>>,
},
Closure {
closure_type: Ustr,
},
}Expand description
A typed parameter that unifies type information with its potential value.
This design makes it impossible to have type mismatches - you can’t accidentally assign an integer default to a color parameter, for example.
Variants
Int
Integer parameter
Float
Float parameter
String
String parameter
Color
RGB color (3 floats)
Point
3D point (3 floats)
Vector
3D vector (3 floats)
Normal
Surface normal (3 floats)
Matrix
4x4 transformation matrix (16 floats)
IntArray
Fixed-size array of integers
FloatArray
Fixed-size array of floats
StringArray
Fixed-size array of strings
ColorArray
Fixed-size array of colors
PointArray
Fixed-size array of points
VectorArray
Fixed-size array of vectors
NormalArray
Fixed-size array of normals
MatrixArray
Fixed-size array of matrices
IntDynamicArray
Dynamic (unsized) array of integers
FloatDynamicArray
Dynamic array of floats
StringDynamicArray
Dynamic array of strings
ColorDynamicArray
Dynamic array of colors
PointDynamicArray
Dynamic array of points
VectorDynamicArray
Dynamic array of vectors
NormalDynamicArray
Dynamic array of normals
MatrixDynamicArray
Dynamic array of matrices
Closure
Closure (BSDF, etc.) - no default values
Implementations
Sourceimpl TypedParameter
impl TypedParameter
Sourcepub fn has_default(&self) -> bool
pub fn has_default(&self) -> bool
Check if this parameter has a default value.
Sourcepub fn is_dynamic_array(&self) -> bool
pub fn is_dynamic_array(&self) -> bool
Check if this is a dynamic (unsized) array.
Sourcepub fn is_closure(&self) -> bool
pub fn is_closure(&self) -> bool
Check if this is a closure type.